@@ -17,16 +17,15 @@ class CLI():
     def entry_point(self):
         try:
             self.config = self.config_manager.get_config()
-            self.entries_saved = self.run_app()
+            self.import_output = self.run_app()
             self.show_entries_saved()
+            self.show_entries_not_saved()
         except ConfigException:
             self.handle_config_problem()
         except (TogglCommunicationException, RedmineServerError):
             self.handle_services_unavailable()
         except (TogglCredentialsException, RedmineAuthException) as e:
             self.handle_credentials_problem(e)
-        except TimeEntryValidationError as e:
-            self.handle_time_entry_validation_problem(e)
         except Exception as e:
             self.handle_the_unknown(e)
 
@@ -34,11 +33,18 @@ class CLI():
         return toggl_to_redmine(self.config)
 
     def show_entries_saved(self):
-        click.echo("\nRegistros salvos:")
-        for entry in self.entries_saved:
+        click.echo("\nRecords saved:")
+        for entry in self.import_output['entries_saved']:
             click.echo(
                 f'{entry.issue_id}: {entry.comment} ({entry.timestamp})')
         click.echo()
+    
+    def show_entries_not_saved(self):
+        click.echo("\n\nRecords that were not saved:")
+        for entry in self.import_output['entries_not_saved']:
+            click.echo(
+                f'{entry.id}: {entry.comment} ({entry.timestamp}) Message: {entry.message}')
+        click.echo()
 
     def handle_config_problem(self):
         click.echo('\nHello! We need to setup your configs on Toggl-to-Redmine.')
@@ -59,14 +65,6 @@ class CLI():
         else:
             click.echo("\nYou could take a look in the config file, then.")
 
-    def handle_time_entry_validation_problem(self, exception: Exception):
-        click.echo(
-            "\nThere was a problem with at least one of your Time Entries.")
-        click.echo(
-            "One of them is not following the pattern required for the import.")
-        click.echo("You can try again after fixing it.")
-        click.echo(f'Error message: {exception}\n')
-
     def handle_the_unknown(self, exception: Exception):
         click.echo(
             "Something unexpected happened. Contact the package maintainer.\n")
